diff --git a/.gradle/8.2.1/checksums/checksums.lock b/.gradle/8.2.1/checksums/checksums.lock
index 0116a20..ff263c3 100644
Binary files a/.gradle/8.2.1/checksums/checksums.lock and b/.gradle/8.2.1/checksums/checksums.lock differ
diff --git a/.gradle/8.2.1/fileHashes/fileHashes.lock b/.gradle/8.2.1/fileHashes/fileHashes.lock
index ae4fef3..a435248 100644
--- a/.gradle/8.2.1/fileHashes/fileHashes.lock
+++ b/.gradle/8.2.1/fileHashes/fileHashes.lock
@@ -1 +1 @@
-�[�i5���
+�[�i5���
\ No newline at end of file
diff --git a/src/main/java/com/zivilon/cinder_loe/entity/DwarfLevy.java b/src/main/java/com/zivilon/cinder_loe/entity/DwarfLevy.java
new file mode 100644
index 0000000..29a3d5c
--- /dev/null
+++ b/src/main/java/com/zivilon/cinder_loe/entity/DwarfLevy.java
@@ -0,0 +1,51 @@
+package com.zivilon.cinder_loe.entity;
+
+import com.zivilon.cinder_loe.CinderLoE;
+import lotr.common.LOTRMod;
+import lotr.common.LOTRShields;
+import lotr.common.entity.npc.LOTREntityDwarfWarrior;
+import net.minecraft.entity.IEntityLivingData;
+import net.minecraft.init.Items;
+import net.minecraft.item.Item;
+import net.minecraft.item.ItemStack;
+import net.minecraft.util.MovingObjectPosition;
+import net.minecraft.world.World;
+
+public class DwarfLevy extends LOTREntityDwarfWarrior {
+
+    private static ItemStack[] levyWeapons = new ItemStack[]{new ItemStack(LOTRMod.daggerDwarven), new ItemStack(LOTRMod.daggerDwarvenPoisoned), new ItemStack(LOTRMod.swordDwarven), new ItemStack(LOTRMod.axeDwarven), new ItemStack(LOTRMod.battleaxeDwarven), new ItemStack(LOTRMod.hammerDwarven), new ItemStack(Items.iron_axe), new ItemStack(LOTRMod.battleaxeIron), new ItemStack(LOTRMod.spearDwarven), new ItemStack(LOTRMod.spearIron)};
+    private static ItemStack[] levySpears = new ItemStack[]{new ItemStack(LOTRMod.spearDwarven), new ItemStack(LOTRMod.spearIron)};
+    private static ItemStack[] levyBodies = new ItemStack[]{new ItemStack(Items.leather_chestplate), new ItemStack(LOTRMod.bodyDaleGambeson)};
+    private static ItemStack[] levyLegs = new ItemStack[]{new ItemStack(Items.leather_leggings), new ItemStack(Items.iron_leggings)};
+    private static ItemStack[] levyBoots = new ItemStack[]{new ItemStack(Items.leather_boots), new ItemStack(LOTRMod.bootsBronze), null};
+    private static final int[] colors = new int[]{14823729, 5512477, 14196753, 11374145, 7366222};
+
+    public DwarfLevy(World world) {
+        super(world);
+        this.npcShield = null;
+    }
+
+    public IEntityLivingData onSpawnWithEgg(IEntityLivingData data) {
+        data = super.onSpawnWithEgg(data);
+        int i = (this).rand.nextInt(levyWeapons.length);
+        this.npcItemsInv.setMeleeWeapon(levyWeapons[i].copy());
+        this.npcItemsInv.setIdleItem(this.npcItemsInv.getMeleeWeapon());
+        if ((this).rand.nextInt(5) == 0) {
+            this.npcItemsInv.setSpearBackup(this.npcItemsInv.getMeleeWeapon());
+            i = (this).rand.nextInt(levySpears.length);
+            this.npcItemsInv.setMeleeWeapon(levySpears[i].copy());
+        }
+        i = (this).rand.nextInt(levyBoots.length);
+        this.setCurrentItemOrArmor(1, levyBoots[i].copy());
+        i = (this).rand.nextInt(levyLegs.length);
+        this.setCurrentItemOrArmor(2, levyLegs[i].copy());
+        i = (this).rand.nextInt(levyBodies.length);
+        this.setCurrentItemOrArmor(3, levyBodies[i].copy());
+        this.setCurrentItemOrArmor(4, null);
+        return data;
+    }
+    @Override
+    public ItemStack getPickedResult(MovingObjectPosition target) {
+        return new ItemStack(CinderLoE.redDwarfWarriorSpawnEgg, 1);
+    }
+}
diff --git a/src/main/java/com/zivilon/cinder_loe/entity/HaradLevy.java b/src/main/java/com/zivilon/cinder_loe/entity/HaradLevy.java
new file mode 100644
index 0000000..f7b004e
--- /dev/null
+++ b/src/main/java/com/zivilon/cinder_loe/entity/HaradLevy.java
@@ -0,0 +1,54 @@
+package com.zivilon.cinder_loe.entity;
+
+import com.zivilon.cinder_loe.CinderLoE;
+import lotr.common.LOTRMod;
+import lotr.common.LOTRShields;
+import lotr.common.entity.npc.LOTREntityBreeGuard;
+import lotr.common.entity.npc.LOTREntityNearHaradrim;
+import lotr.common.item.LOTRItemHaradRobes;
+import net.minecraft.entity.IEntityLivingData;
+import net.minecraft.init.Items;
+import net.minecraft.item.ItemStack;
+import net.minecraft.world.World;
+
+public class HaradLevy extends LOTREntityNearHaradrim {
+    private static ItemStack[] levyWeapons = new ItemStack[]{new ItemStack(LOTRMod.daggerHarad), new ItemStack(LOTRMod.daggerHaradPoisoned), new ItemStack(LOTRMod.swordHarad), new ItemStack(LOTRMod.swordMoredain), new ItemStack(LOTRMod.battleaxeBronze), new ItemStack(LOTRMod.maceNearHarad), new ItemStack(Items.iron_sword), new ItemStack(LOTRMod.swordBronze), new ItemStack(LOTRMod.battleaxeIron), new ItemStack(LOTRMod.poleaxeNearHarad), new ItemStack(LOTRMod.spearHarad), new ItemStack(LOTRMod.spearIron), new ItemStack(LOTRMod.spearBronze)};
+    private static ItemStack[] levySpears = new ItemStack[]{new ItemStack(LOTRMod.spearHarad), new ItemStack(LOTRMod.spearIron), new ItemStack(LOTRMod.spearBronze)};
+    private static ItemStack[] levyBodies = new ItemStack[]{new ItemStack(Items.leather_chestplate), new ItemStack(LOTRMod.bodyBronze), new ItemStack(LOTRMod.bodyHaradRobes)};
+    private static ItemStack[] levyLegs = new ItemStack[]{new ItemStack(Items.leather_leggings), new ItemStack(LOTRMod.legsBronze)};
+    private static ItemStack[] levyBoots = new ItemStack[]{new ItemStack(Items.leather_boots), new ItemStack(LOTRMod.bootsBronze), null};
+    private static final int[] colors = new int[]{14823729, 5512477, 14196753, 11374145, 7366222};
+
+    public HaradLevy(World world) {
+        super(world);
+        this.spawnRidingHorse = false;
+        this.addTargetTasks(true);
+        this.npcShield = null;
+    }
+
+    @Override
+    public void setupNPCGender() {
+        this.familyInfo.setMale(true);
+    }
+
+    @Override
+    public IEntityLivingData onSpawnWithEgg(IEntityLivingData data) {
+        data = super.onSpawnWithEgg(data);
+        int i = (this).rand.nextInt(levyWeapons.length);
+        this.npcItemsInv.setMeleeWeapon(levyWeapons[i].copy());
+        this.npcItemsInv.setIdleItem(this.npcItemsInv.getMeleeWeapon());
+        if ((this).rand.nextInt(5) == 0) {
+            this.npcItemsInv.setSpearBackup(this.npcItemsInv.getMeleeWeapon());
+            i = (this).rand.nextInt(levySpears.length);
+            this.npcItemsInv.setMeleeWeapon(levySpears[i].copy());
+        }
+        i = (this).rand.nextInt(levyBoots.length);
+        this.setCurrentItemOrArmor(1, levyBoots[i].copy());
+        i = (this).rand.nextInt(levyLegs.length);
+        this.setCurrentItemOrArmor(2, levyLegs[i].copy());
+        i = (this).rand.nextInt(levyBodies.length);
+        this.setCurrentItemOrArmor(3, levyBodies[i].copy());
+        this.setCurrentItemOrArmor(4, null);
+        return data;
+    }
+}
diff --git a/src/main/java/com/zivilon/cinder_loe/mixins/MixinLOTRContainerAnvil.java b/src/main/java/com/zivilon/cinder_loe/mixins/MixinLOTRContainerAnvil.java
index 2d456ed..db8a133 100644
--- a/src/main/java/com/zivilon/cinder_loe/mixins/MixinLOTRContainerAnvil.java
+++ b/src/main/java/com/zivilon/cinder_loe/mixins/MixinLOTRContainerAnvil.java
@@ -56,7 +56,7 @@ public class MixinLOTRContainerAnvil {
         if (material == CinderLoE.MATERIAL_ASH.toToolMaterial())
             return (materialItem.getItem() == CinderLoE.ingotAsh);
         if (material == CinderLoE.MATERIAL_LIMWAITH_BONE.toToolMaterial())
-            return LOTRMod.isOreNameEqual(materialItem, "bone");
+            return (materialItem.getItem() == CinderLoE.bonemold);
         if (material == CinderLoE.EVENT.toToolMaterial())
             return LOTRMod.isOreNameEqual(materialItem, "ice");
         if (material == CinderLoE.MATERIAL_BREE.toToolMaterial())
diff --git a/src/main/java/com/zivilon/cinder_loe/CinderLoE.java b/src/main/java/com/zivilon/cinder_loe/CinderLoE.java
index f2bb164..bb280b2 100644
--- a/src/main/java/com/zivilon/cinder_loe/CinderLoE.java
+++ b/src/main/java/com/zivilon/cinder_loe/CinderLoE.java
@@ -299,10 +299,14 @@ public class CinderLoE {
         event.registerServerCommand(new CommandCinderCharacter());
     }
 
-    public void registerEntities() { // Last ID added: 35
+    public void registerEntities() { // Last ID added: 37
         GameRegistry.registerTileEntity(TileEntityMistBlock.class, "TileEntityMistBlock");
 
         int entityID = 7320; // Always increment entityID by 1 over the last entity to ensure unique IDs
+        EntityRegistry.registerModEntity(HaradLevy.class, "HaradLevy", (entityID + 36), this, 64, 1, true);
+        EntityRegistry.registerModEntity(DwarfLevy.class, "DwarfLevy", (entityID + 37), this, 64, 1, true);
+
+
         EntityRegistry.registerModEntity(SarumanFireball.class, "SarumanFireball", entityID + 0, this, 64, 10, true);
         EntityRegistry.registerModEntity(Renegade.class, "Renegade", (entityID + 1), this, 64, 1, true);
         EntityRegistry.registerModEntity(RenegadeCaptain.class, "RenegadeCaptain", (entityID + 16), this, 64, 1, true);
@@ -779,6 +783,9 @@ public class CinderLoE {
     public static class ClientProxy extends CommonProxy {
         @Override
         public void setup() {
+            RenderingRegistry.registerEntityRenderingHandler(HaradLevy.class, new LOTRRenderNearHaradrim());
+            RenderingRegistry.registerEntityRenderingHandler(DwarfLevy.class, new LOTRRenderDwarf());
+
             RenderingRegistry.registerEntityRenderingHandler(SarumanFireball.class, new RenderSarumanFireball());
             RenderingRegistry.registerEntityRenderingHandler(Renegade.class, new RenderRenegade());
             RenderingRegistry.registerEntityRenderingHandler(RenegadeCaptain.class, new RenderRenegade());
@@ -1051,6 +1058,9 @@ public class CinderLoE {
         CinderCore.registerItemFallback(Item.getIdFromItem(bootsArnorBanner), Item.getIdFromItem(Items.chainmail_boots), "cinder_loe", "1.1");
         CinderCore.registerItemFallback(Item.getIdFromItem(maceArnor), Item.getIdFromItem(LOTRMod.blacksmithHammer), "cinder_loe", "1.1");
 
+        CinderCore.registerEntityFallback(HaradLevy.class, LOTREntityNearHaradrim.class, "cinder_loe", "1.2");
+        CinderCore.registerEntityFallback(DwarfLevy.class, LOTREntityDwarf.class, "cinder_loe", "1.2");
+
         CinderCore.registerEntityFallback(SarumanFireball.class, LOTREntityGandalfFireball.class, "cinder_loe", "1.0");
         CinderCore.registerEntityFallback(Renegade.class, LOTREntityBandit.class, "cinder_loe", "1.0");
         CinderCore.registerEntityFallback(RenegadeCaptain.class, LOTREntityBandit.class, "cinder_loe", "1.1");
diff --git a/src/main/resources/assets/cinder_loe/mob/corrupt/dwarf/0.png b/src/main/resources/assets/cinder_loe/mob/corrupt/dwarf/0.png
new file mode 100644
index 0000000..c9399b3
Binary files /dev/null and b/src/main/resources/assets/cinder_loe/mob/corrupt/dwarf/0.png differ
diff --git a/src/main/resources/assets/cinder_loe/mob/corrupt/dwarf/1.png b/src/main/resources/assets/cinder_loe/mob/corrupt/dwarf/1.png
new file mode 100644
index 0000000..634e017
Binary files /dev/null and b/src/main/resources/assets/cinder_loe/mob/corrupt/dwarf/1.png differ
diff --git a/src/main/resources/assets/cinder_loe/mob/corrupt/elf_female/0.png b/src/main/resources/assets/cinder_loe/mob/corrupt/elf_female/0.png
new file mode 100644
index 0000000..f253d46
Binary files /dev/null and b/src/main/resources/assets/cinder_loe/mob/corrupt/elf_female/0.png differ
diff --git a/src/main/resources/assets/cinder_loe/mob/corrupt/elf_female/1.png b/src/main/resources/assets/cinder_loe/mob/corrupt/elf_female/1.png
new file mode 100644
index 0000000..e7b78d6
Binary files /dev/null and b/src/main/resources/assets/cinder_loe/mob/corrupt/elf_female/1.png differ
diff --git a/src/main/resources/assets/cinder_loe/mob/corrupt/elf_female/2.png b/src/main/resources/assets/cinder_loe/mob/corrupt/elf_female/2.png
new file mode 100644
index 0000000..a9264b4
Binary files /dev/null and b/src/main/resources/assets/cinder_loe/mob/corrupt/elf_female/2.png differ
diff --git a/src/main/resources/assets/cinder_loe/mob/corrupt/elf_male/0.png b/src/main/resources/assets/cinder_loe/mob/corrupt/elf_male/0.png
new file mode 100644
index 0000000..3bc81be
Binary files /dev/null and b/src/main/resources/assets/cinder_loe/mob/corrupt/elf_male/0.png differ
diff --git a/src/main/resources/assets/cinder_loe/mob/corrupt/elf_male/1.png b/src/main/resources/assets/cinder_loe/mob/corrupt/elf_male/1.png
new file mode 100644
index 0000000..7f3f0b9
Binary files /dev/null and b/src/main/resources/assets/cinder_loe/mob/corrupt/elf_male/1.png differ
diff --git a/src/main/resources/assets/cinder_loe/mob/corrupt/elf_male/2.png b/src/main/resources/assets/cinder_loe/mob/corrupt/elf_male/2.png
new file mode 100644
index 0000000..a854dcb
Binary files /dev/null and b/src/main/resources/assets/cinder_loe/mob/corrupt/elf_male/2.png differ
diff --git a/src/main/resources/assets/cinder_loe/mob/corrupt/ent/beech.png b/src/main/resources/assets/cinder_loe/mob/corrupt/ent/beech.png
new file mode 100644
index 0000000..423d411
Binary files /dev/null and b/src/main/resources/assets/cinder_loe/mob/corrupt/ent/beech.png differ
diff --git a/src/main/resources/assets/cinder_loe/mob/corrupt/ent/birch.png b/src/main/resources/assets/cinder_loe/mob/corrupt/ent/birch.png
new file mode 100644
index 0000000..e3d5a56
Binary files /dev/null and b/src/main/resources/assets/cinder_loe/mob/corrupt/ent/birch.png differ
diff --git a/src/main/resources/assets/cinder_loe/mob/corrupt/ent/oak.png b/src/main/resources/assets/cinder_loe/mob/corrupt/ent/oak.png
new file mode 100644
index 0000000..0f0b368
Binary files /dev/null and b/src/main/resources/assets/cinder_loe/mob/corrupt/ent/oak.png differ
diff --git a/src/main/resources/assets/cinder_loe/mob/corrupt/hobbit_female/0.png b/src/main/resources/assets/cinder_loe/mob/corrupt/hobbit_female/0.png
new file mode 100644
index 0000000..eb60cd3
Binary files /dev/null and b/src/main/resources/assets/cinder_loe/mob/corrupt/hobbit_female/0.png differ
diff --git a/src/main/resources/assets/cinder_loe/mob/corrupt/hobbit_female/1.png b/src/main/resources/assets/cinder_loe/mob/corrupt/hobbit_female/1.png
new file mode 100644
index 0000000..dd3c554
Binary files /dev/null and b/src/main/resources/assets/cinder_loe/mob/corrupt/hobbit_female/1.png differ
diff --git a/src/main/resources/assets/cinder_loe/mob/corrupt/hobbit_male/0.png b/src/main/resources/assets/cinder_loe/mob/corrupt/hobbit_male/0.png
new file mode 100644
index 0000000..35bec49
Binary files /dev/null and b/src/main/resources/assets/cinder_loe/mob/corrupt/hobbit_male/0.png differ
diff --git a/src/main/resources/assets/cinder_loe/mob/corrupt/hobbit_male/1.png b/src/main/resources/assets/cinder_loe/mob/corrupt/hobbit_male/1.png
new file mode 100644
index 0000000..7da29df
Binary files /dev/null and b/src/main/resources/assets/cinder_loe/mob/corrupt/hobbit_male/1.png differ
diff --git a/src/main/resources/assets/cinder_loe/mob/corrupt/human_female/0.png b/src/main/resources/assets/cinder_loe/mob/corrupt/human_female/0.png
new file mode 100644
index 0000000..306b75d
Binary files /dev/null and b/src/main/resources/assets/cinder_loe/mob/corrupt/human_female/0.png differ
diff --git a/src/main/resources/assets/cinder_loe/mob/corrupt/human_female/1.png b/src/main/resources/assets/cinder_loe/mob/corrupt/human_female/1.png
new file mode 100644
index 0000000..92b57cb
Binary files /dev/null and b/src/main/resources/assets/cinder_loe/mob/corrupt/human_female/1.png differ
diff --git a/src/main/resources/assets/cinder_loe/mob/corrupt/human_female/2.png b/src/main/resources/assets/cinder_loe/mob/corrupt/human_female/2.png
new file mode 100644
index 0000000..480279d
Binary files /dev/null and b/src/main/resources/assets/cinder_loe/mob/corrupt/human_female/2.png differ
diff --git a/src/main/resources/assets/cinder_loe/mob/corrupt/human_male/0.png b/src/main/resources/assets/cinder_loe/mob/corrupt/human_male/0.png
new file mode 100644
index 0000000..7d3734c
Binary files /dev/null and b/src/main/resources/assets/cinder_loe/mob/corrupt/human_male/0.png differ
diff --git a/src/main/resources/assets/cinder_loe/mob/corrupt/human_male/1.png b/src/main/resources/assets/cinder_loe/mob/corrupt/human_male/1.png
new file mode 100644
index 0000000..3b5b3ad
Binary files /dev/null and b/src/main/resources/assets/cinder_loe/mob/corrupt/human_male/1.png differ
diff --git a/src/main/resources/assets/cinder_loe/mob/corrupt/human_male/2.png b/src/main/resources/assets/cinder_loe/mob/corrupt/human_male/2.png
new file mode 100644
index 0000000..23acbcb
Binary files /dev/null and b/src/main/resources/assets/cinder_loe/mob/corrupt/human_male/2.png differ
diff --git a/src/main/resources/assets/cinder_loe/mob/corrupt/human_male/3.png b/src/main/resources/assets/cinder_loe/mob/corrupt/human_male/3.png
new file mode 100644
index 0000000..64aa1b4
Binary files /dev/null and b/src/main/resources/assets/cinder_loe/mob/corrupt/human_male/3.png differ
diff --git a/src/main/resources/assets/cinder_loe/mob/corrupt/orc/0.png b/src/main/resources/assets/cinder_loe/mob/corrupt/orc/0.png
new file mode 100644
index 0000000..8c52f50
Binary files /dev/null and b/src/main/resources/assets/cinder_loe/mob/corrupt/orc/0.png differ
diff --git a/src/main/resources/assets/cinder_loe/mob/corrupt/orc/1.png b/src/main/resources/assets/cinder_loe/mob/corrupt/orc/1.png
new file mode 100644
index 0000000..88ea719
Binary files /dev/null and b/src/main/resources/assets/cinder_loe/mob/corrupt/orc/1.png differ
diff --git a/src/main/resources/assets/cinder_loe/mob/corrupt/orc/2.png b/src/main/resources/assets/cinder_loe/mob/corrupt/orc/2.png
new file mode 100644
index 0000000..67a5b60
Binary files /dev/null and b/src/main/resources/assets/cinder_loe/mob/corrupt/orc/2.png differ
diff --git a/src/main/resources/assets/cinder_loe/mob/halfTroll/halfTroll/0.png b/src/main/resources/assets/cinder_loe/mob/halfTroll/halfTroll/0.png
new file mode 100644
index 0000000..d3f354c
Binary files /dev/null and b/src/main/resources/assets/cinder_loe/mob/halfTroll/halfTroll/0.png differ
diff --git a/src/main/resources/assets/cinder_loe/mob/halfTroll/halfTroll/1.png b/src/main/resources/assets/cinder_loe/mob/halfTroll/halfTroll/1.png
new file mode 100644
index 0000000..edc4568
Binary files /dev/null and b/src/main/resources/assets/cinder_loe/mob/halfTroll/halfTroll/1.png differ
diff --git a/src/main/resources/assets/cinder_loe/mob/halfTroll/halfTroll/2.png b/src/main/resources/assets/cinder_loe/mob/halfTroll/halfTroll/2.png
new file mode 100644
index 0000000..877e6c8
Binary files /dev/null and b/src/main/resources/assets/cinder_loe/mob/halfTroll/halfTroll/2.png differ
diff --git a/src/main/resources/assets/cinder_loe/mob/halfTroll/half_troll_1.png b/src/main/resources/assets/cinder_loe/mob/halfTroll/half_troll_1.png
new file mode 100644
index 0000000..3019647
Binary files /dev/null and b/src/main/resources/assets/cinder_loe/mob/halfTroll/half_troll_1.png differ
diff --git a/src/main/resources/assets/cinder_loe/mob/halfTroll/half_troll_2.png b/src/main/resources/assets/cinder_loe/mob/halfTroll/half_troll_2.png
new file mode 100644
index 0000000..e43aa12
Binary files /dev/null and b/src/main/resources/assets/cinder_loe/mob/halfTroll/half_troll_2.png differ
diff --git a/src/main/resources/assets/cinder_loe/mob/halfTroll/scavenger.png b/src/main/resources/assets/cinder_loe/mob/halfTroll/scavenger.png
new file mode 100644
index 0000000..ab48769
Binary files /dev/null and b/src/main/resources/assets/cinder_loe/mob/halfTroll/scavenger.png differ
